# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Calendar Versioning](https://calver.org).

## [23.3] - 2023-08-23

Added video demo to the project description 🎉

### Added

- Video Demo

## [23.2] - 2023-08-23

Add about screen.

### Added

- About screen

## [23.1] - 2023-08-23

Fix crash on startup.

### Fixed

- Crash when a command module doesn't have a `Command` class.




## [23.0] - 2023-08-23

Initial Release!
